#ifndef __NRF_PWM_H__
#define __NRF_PWM_H__

#include <stdint.h>

// The maximum number of channels supported by the library. Should NOT be changed! 
#define PWM_MAX_CHANNELS        3

// Set this to 1 if the application uses a SoftDevice, 0 otherwise
#define USE_WITH_SOFTDEVICE     0

// To change the timer used for the PWM library replace the three defines below
#define PWM_TIMER               NRF_TIMER2
#define PWM_IRQHandler          TIMER2_IRQHandler
#define PWM_IRQn                TIMER2_IRQn
#define PWM_IRQ_PRIORITY        3

#define PWM_DEFAULT_CONFIG  {.num_channels   = 3,                \
                             .gpio_num       = {8,9,10},         \
                             .ppi_channel    = {0,1,2,3,4,5},    \
                             .gpiote_channel = {2,3,0},          \
                             .mode           = PWM_MODE_LED_100};

typedef enum
{
    PWM_MODE_LED_100,   // 0-100 resolution, 156 Hz PWM frequency, 32 kHz timer frequency (prescaler 9)
    PWM_MODE_LED_255,   // 8-bit resolution, 122 Hz PWM frequency, 65 kHz timer frequency (prescaler 8)
    PWM_MODE_LED_1000,  // 0-1000 resolution, 125 Hz PWM frequency, 500 kHz timer frequency (prescaler 5)
    
    PWM_MODE_MTR_100,   // 0-100 resolution, 20 kHz PWM frequency, 4MHz timer frequency (prescaler 2)
    PWM_MODE_MTR_255,   // 8-bit resolution, 31 kHz PWM frequency, 16MHz timer frequency (prescaler 0)
    
    PWM_MODE_BUZZER_64,  // 0-64  resolution, 125 kHz PWM frequency, 16 MHz timer frequency (prescaler 0)
    PWM_MODE_BUZZER_2730HZ // From Torbjorn at Nordic
} nrf_pwm_mode_t;

typedef struct
{
    uint8_t         num_channels;
    uint8_t         gpio_num[3];
    uint8_t         ppi_channel[6];
    uint8_t         gpiote_channel[3];
    uint8_t         mode;
} nrf_pwm_config_t; 

uint32_t nrf_pwm_init(nrf_pwm_config_t *config);

void nrf_pwm_set_value(uint32_t pwm_channel, uint32_t pwm_value);

#endif
